@@ -168,7 +168,8 @@ def test_generate_changelog_with_ai_custom_model():
 
 def test_openai_generate_changelog():
     """Test OpenAI changelog generation."""
-    client = OpenAI()
+    api_key = os.environ.get("OPENAI_API_KEY", "test-key")
+    client = OpenAI(api_key=api_key)
     commits = ["abc123 Fix bug", "def456 Add feature"]
 
     with patch("openai.OpenAI") as mock_openai:
@@ -185,7 +186,8 @@ def test_openai_generate_changelog():
 
 def test_openai_generate_commit_message():
     """Test OpenAI commit message generation."""
-    client = OpenAI()
+    api_key = os.environ.get("OPENAI_API_KEY", "test-key")
+    client = OpenAI(api_key=api_key)
     changes = ["file1.py", "file2.py"]
 
     with patch("openai.OpenAI") as mock_openai:
